watex: A machine learning in hydro-geophysics — watex 0.1.3 documentation

Skip to main content
`Ctrl`+`K`

# watex: A machine learning in hydro-geophysics

Synopsis

WATex is a Python package focused on the groundwater exploration field. It brings piece solutions to minimize the losses during the hydro-geophysical engineering projects. It uses the geophysical methods combined with the machine learning approaches to predict some water content targets. More about the ideas behind the package can be found in the introductory notes.

To getting started with the software, refer to the installation guide. You can also browse the examples page to see some of the expected results you can achieve using the software. The user guide is more in-depth guide about the different methods implemented supported by theories and concrete examples.

Contents

- Install
- API
- User Guide
- Examples
- About
- Citing